use actix_identity::Identity;
use actix_web::{web, HttpMessage, HttpRequest, HttpResponse, Responder};
use serde::Deserialize;
use sqlx::SqlitePool;

use crate::{auth::utils::hash_plain_password_with_salt, models::user::User};

#[derive(Deserialize)]
struct LoginForm {
    name: String,
    password: String,
}

#[actix_web::post("/login")]
async fn route(
    web::Form(form): web::Form<LoginForm>,
    request: HttpRequest,
    pool: web::Data<SqlitePool>,
) -> impl Responder {
    match User::read_by_name(pool.get_ref(), &form.name).await {
        Some(potential_user) => {
            let hash = hash_plain_password_with_salt(&form.password, &potential_user.salt).unwrap();

            if hash == potential_user.password_hash {
                Identity::login(&request.extensions(), potential_user.id.to_string());

                return HttpResponse::Ok().body("Angemeldet!");
            } else {
                return HttpResponse::Unauthorized().body("Nutzername oder Passwort falsch.");
            }
        }
        None => return HttpResponse::Unauthorized().body("Nutzername oder Passwort falsch."),
    }
}
