use actix_web::{http::header::LOCATION, web, HttpResponse, Responder};
use serde::Deserialize;
use sqlx::SqlitePool;

use crate::{auth::utils::generate_salt_and_hash_plain_password, models::user::User};

#[derive(Deserialize)]
struct RegisterForm {
    name: String,
    password: String,
    role: i64,
}

#[actix_web::post("/register")]
async fn route(
    web::Form(form): web::Form<RegisterForm>,
    pool: web::Data<SqlitePool>,
) -> impl Responder {
    let (hash, salt) = generate_salt_and_hash_plain_password(&form.password).unwrap();

    let result = User::create(pool.get_ref(), form.name, hash, salt, form.role).await;

    match result {
        Ok(_) => {
            return HttpResponse::PermanentRedirect()
                .insert_header((LOCATION, "/"))
                .finish()
        }
        Err(err) => return HttpResponse::BadRequest().body(err.to_string()),
    }
}
