use sqlx::sqlite::SqlitePool;

pub struct User {
    pub id: i64,
    pub name: String,
    pub password_hash: String,
    pub salt: String,
    pub role_id: i64,
}

impl User {
    pub async fn create(
        pool: &SqlitePool,
        name: String,
        password_hash: String,
        salt: String,
        role_id: i64,
    ) -> anyhow::Result<i64> {
        let created = sqlx::query!(
            r#"
                INSERT INTO users (name, password_hash, salt, role_id)
                VALUES (?1, ?2, ?3, ?4);
            "#,
            name,
            password_hash,
            salt,
            role_id
        )
        .execute(pool)
        .await;

        match created {
            Ok(result) => Ok(result.last_insert_rowid()),
            Err(err) => Err(err.into()),
        }
    }

    pub async fn read_by_id(pool: &SqlitePool, id: i64) -> Option<User> {
        let record = sqlx::query_as!(
            User,
            r#"
                SELECT *
                FROM users
                WHERE id = ?1;
            "#,
            id,
        )
        .fetch_one(pool)
        .await;

        match record {
            Ok(record) => Some(record),
            Err(err) => {
                println!("User.read({id}): {err}");
                None
            }
        }
    }

    pub async fn read_by_name(pool: &SqlitePool, name: &str) -> Option<User> {
        let record = sqlx::query_as!(
            User,
            r#"
                SELECT *
                FROM users
                WHERE name = ?1;
            "#,
            name
        )
        .fetch_one(pool)
        .await;

        match record {
            Ok(record) => Some(record),
            Err(err) => {
                println!("User.read({name}): {err}");
                None
            }
        }
    }
}
